@@ -102,8 +102,7 @@ PP(pp_initfield)
                 STRLEN svcount = PL_stack_sp - svp + 1;
 
                 if(svcount % 2)
-                    Perl_warner(aTHX_
-                            packWARN(WARN_MISC), "Odd number of elements in hash field initialization");
+                    warner(packWARN(WARN_MISC), "Odd number of elements in hash field initialization");
 
                 while(svp <= PL_stack_sp) {
                     SV *key = *svp; svp++;
@@ -141,11 +140,11 @@ XS(injected_constructor)
     struct xpvhv_aux *aux = HvAUX(stash);
 
     if((items - 1) % 2)
-        Perl_warn(aTHX_ "Odd number of arguments passed to %" HvNAMEf_QUOTEDPREFIX " constructor",
+        warn("Odd number of arguments passed to %" HvNAMEf_QUOTEDPREFIX " constructor",
                 HvNAMEfARG(stash));
 
     if (!aux->xhv_class_initfields_cv) {
-        Perl_croak(aTHX_ "Cannot create an object of incomplete class %" HvNAMEf_QUOTEDPREFIX,
+        croak("Cannot create an object of incomplete class %" HvNAMEf_QUOTEDPREFIX,
                    HvNAMEfARG(stash));
     }
 
@@ -230,7 +229,7 @@ XS(injected_constructor)
         SAVEFREESV(paramnames);
 
         while((he = hv_iternext(params)))
-            Perl_sv_catpvf(aTHX_ paramnames, ", %" SVf, SVfARG(HeSVKEY_force(he)));
+            sv_catpvf(paramnames, ", %" SVf, SVfARG(HeSVKEY_force(he)));
 
         croak("Unrecognised parameters for %" HvNAMEf_QUOTEDPREFIX " constructor: %" SVf,
                 HvNAMEfARG(stash), SVfARG(paramnames));
