@@ -2,10 +2,9 @@ package Test2::EventFacet::Meta;
 use strict;
 use warnings;
 
-our $VERSION = '1.302190';
+our $VERSION = '1.302209';
 
 BEGIN { require Test2::EventFacet; our @ISA = qw(Test2::EventFacet) }
-use vars qw/$AUTOLOAD/;
 
 # replace set_details
 {
@@ -35,7 +34,7 @@ sub can {
 }
 
 sub AUTOLOAD {
-    my $name = $AUTOLOAD;
+    my $name = our $AUTOLOAD;
     $name =~ s/^.*:://g;
     my $sub = $_[0]->can($name);
     goto &$sub;
@@ -74,7 +73,7 @@ to know what metadata may be added, so any is allowed.
 =head1 SOURCE
 
 The source code repository for Test2 can be found at
-F<http://github.com/Test-More/test-more/>.
+L<https://github.com/Test-More/test-more/>.
 
 =head1 MAINTAINERS
 
@@ -94,11 +93,11 @@ F<http://github.com/Test-More/test-more/>.
 
 =head1 COPYRIGHT
 
-Copyright 2020 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://dev.perl.org/licenses/>
+See L<https://dev.perl.org/licenses/>
 
 =cut
