@@ -1,4 +1,4 @@
-package Opcode 1.68;
+package Opcode 1.69;
 
 use strict;
 
@@ -436,6 +436,11 @@ These are a hotchpotch of opcodes still waiting to be considered
     entertry leavetry -- can be used to 'hide' fatal errors
     entertrycatch poptry catch leavetrycatch -- similar
 
+    entergiven leavegiven
+    enterwhen leavewhen
+    break continue
+    smartmatch
+
     pushdefer
 
     custom -- where should this go
