@@ -181,15 +181,15 @@ Perl_uvuni_to_utf8(pTHX_ U8 *d, UV uv)
 =for apidoc_section $unicode
 =for apidoc utf8n_to_uvuni
 
-Instead use L<perlapi/utf8_to_uvchr_buf>, or rarely, L<perlapi/utf8n_to_uvchr>.
+Instead use L<perlapi/utf8_to_uv>, or rarely, L<perlapi/utf8_to_uv_flags>.
 
 This function was useful for code that wanted to handle both EBCDIC and
 ASCII platforms with Unicode properties, but starting in Perl v5.20, the
 distinctions between the platforms have mostly been made invisible to most
 code, so this function is quite unlikely to be what you want.  If you do need
-this precise functionality, use instead
-C<L<NATIVE_TO_UNI(utf8_to_uvchr_buf(...))|perlapi/utf8_to_uvchr_buf>>
-or C<L<NATIVE_TO_UNI(utf8n_to_uvchr(...))|perlapi/utf8n_to_uvchr>>.
+this precise functionality, use instead L<perlapi/C<utf8_to_uv>> or
+L<perlapi/C<utf8_to_uv_flags>> to calculate the native code point, and then
+convert to Unicode using L<perlapi/C<NATIVE_TO_UNI>>.
 
 =cut
 */
