@@ -215,7 +215,7 @@ typedef enum {
  * following header file: */
 #  include "utfebcdic.h"
 
-#  else	/* ! EBCDIC */
+#  else /* ! EBCDIC */
 
 START_EXTERN_C
 
@@ -235,11 +235,11 @@ EXTCONST unsigned char PL_utf8skip[] = {
 /* 0x90 */ 1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1, /* bogus: continuation byte */
 /* 0xA0 */ 1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1, /* bogus: continuation byte */
 /* 0xB0 */ 1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1, /* bogus: continuation byte */
-/* 0xC0 */ 2,2,				    /* overlong */
+/* 0xC0 */ 2,2,                             /* overlong */
 /* 0xC2 */     2,2,2,2,2,2,2,2,2,2,2,2,2,2, /* U+0080 to U+03FF */
 /* 0xD0 */ 2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2, /* U+0400 to U+07FF */
 /* 0xE0 */ 3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3, /* U+0800 to U+FFFF */
-/* 0xF0 */ 4,4,4,4,4,4,4,4,5,5,5,5,6,6,	    /* above BMP to 2**31 - 1 */
+/* 0xF0 */ 4,4,4,4,4,4,4,4,5,5,5,5,6,6,     /* above BMP to 2**31 - 1 */
            /* Perl extended (never was official UTF-8).  Up to 36 bit */
 /* 0xFE */                             7,
            /* More extended, Up to 72 bits (64-bit + reserved) */
@@ -314,21 +314,21 @@ adding no time nor space requirements to the implementation.
  The following table is from Unicode 3.2, plus the Perl extensions for above
  U+10FFFF
 
- Code Points		1st Byte  2nd Byte  3rd    4th     5th     6th       7th   8th-13th
+ Code Points           1st Byte  2nd Byte  3rd    4th     5th     6th       7th   8th-13th
 
-   U+0000..U+007F	00..7F
+   U+0000..U+007F       00..7F
    U+0080..U+07FF     * C2..DF    80..BF
-   U+0800..U+0FFF	E0      * A0..BF  80..BF
+   U+0800..U+0FFF       E0      * A0..BF  80..BF
    U+1000..U+CFFF       E1..EC    80..BF  80..BF
    U+D000..U+D7FF       ED        80..9F  80..BF
    U+D800..U+DFFF       ED        A0..BF  80..BF  (surrogates)
    U+E000..U+FFFF       EE..EF    80..BF  80..BF
-  U+10000..U+3FFFF	F0      * 90..BF  80..BF  80..BF
-  U+40000..U+FFFFF	F1..F3    80..BF  80..BF  80..BF
- U+100000..U+10FFFF	F4        80..8F  80..BF  80..BF
+  U+10000..U+3FFFF      F0      * 90..BF  80..BF  80..BF
+  U+40000..U+FFFFF      F1..F3    80..BF  80..BF  80..BF
+ U+100000..U+10FFFF     F4        80..8F  80..BF  80..BF
     Below are above-Unicode code points
- U+110000..U+13FFFF	F4        90..BF  80..BF  80..BF
- U+110000..U+1FFFFF	F5..F7    80..BF  80..BF  80..BF
+ U+110000..U+13FFFF     F4        90..BF  80..BF  80..BF
+ U+110000..U+1FFFFF     F5..F7    80..BF  80..BF  80..BF
  U+200000..U+FFFFFF     F8      * 88..BF  80..BF  80..BF  80..BF
 U+1000000..U+3FFFFFF    F9..FB    80..BF  80..BF  80..BF  80..BF
 U+4000000..U+3FFFFFFF    FC     * 84..BF  80..BF  80..BF  80..BF  80..BF
@@ -670,7 +670,7 @@ encoded as UTF-8.  C<cp> is a native (ASCII or EBCDIC) code point if less than
 /* Is the UTF8-encoded byte 'c' the first byte of a two byte sequence?  Use
  * UTF8_IS_NEXT_CHAR_DOWNGRADEABLE() instead if the input isn't known to
  * be well-formed. */
-#define UTF8_IS_DOWNGRADEABLE_START(c)	(__ASSERT_(FITS_IN_8_BITS(c))       \
+#define UTF8_IS_DOWNGRADEABLE_START(c)  (__ASSERT_(FITS_IN_8_BITS(c))       \
                 inRANGE_helper_(U8, NATIVE_UTF8_TO_I8(c),                   \
                         UTF_MIN_START_BYTE, UTF_MIN_ABOVE_LATIN1_BYTE - 1))
 
@@ -711,7 +711,7 @@ uppercase/lowercase/titlecase/fold into.
  *
 =cut
 */
-#define UTF8_MAXBYTES_CASE	                                            \
+#define UTF8_MAXBYTES_CASE                                                  \
         MAX(UTF8_MAXBYTES, UTF8_MAX_FOLD_CHAR_EXPAND * UNISKIP_BY_MSB_(20))
 
 /* Rest of these are attributes of Unicode and perl's internals rather than the
@@ -859,11 +859,11 @@ that it returns TRUE in each for the exact same set of bit patterns.  It is
 valid on a subset of what UVCHR_IS_INVARIANT is valid on, so can just use that;
 and the compiler should optimize out anything extraneous given the
 implementation of the latter. */
-#define UTF8_IS_INVARIANT(c)	UVCHR_IS_INVARIANT(ASSERT_NOT_PTR(c))
+#define UTF8_IS_INVARIANT(c)    UVCHR_IS_INVARIANT(ASSERT_NOT_PTR(c))
 
 /* Like the above, but its name implies a non-UTF8 input, which as the comments
  * above show, doesn't matter as to its implementation */
-#define NATIVE_BYTE_IS_INVARIANT(c)	UVCHR_IS_INVARIANT(c)
+#define NATIVE_BYTE_IS_INVARIANT(c)     UVCHR_IS_INVARIANT(c)
 
 /* Misleadingly named: is the UTF8-encoded byte 'c' part of a variant sequence
  * in UTF-8?  This is the inverse of UTF8_IS_INVARIANT. */
@@ -967,8 +967,8 @@ case any call to string overloading updates the internal UTF-8 encoding flag.
                        && is_in_locale_category_(FALSE, -1)))           \
               && (! IN_BYTES))
 
-#define UNICODE_SURROGATE_FIRST		0xD800
-#define UNICODE_SURROGATE_LAST		0xDFFF
+#define UNICODE_SURROGATE_FIRST         0xD800
+#define UNICODE_SURROGATE_LAST          0xDFFF
 
 /*
 =for apidoc Am|bool|UNICODE_IS_SURROGATE|const UV uv
@@ -1012,7 +1012,7 @@ representation.
 
 =cut
  */
-#define UNICODE_REPLACEMENT		0xFFFD
+#define UNICODE_REPLACEMENT         0xFFFD
 #define UNICODE_IS_REPLACEMENT(uv)  UNLIKELY((UV) (uv) == UNICODE_REPLACEMENT)
 #define UTF8_IS_REPLACEMENT(s, send)                                         \
     UNLIKELY(                                                                \
@@ -1021,7 +1021,7 @@ representation.
                       sizeof(REPLACEMENT_CHARACTER_UTF8) - 1))
 
 /* Max legal code point according to Unicode */
-#define PERL_UNICODE_MAX	0x10FFFF
+#define PERL_UNICODE_MAX            0x10FFFF
 
 /*
 
@@ -1057,21 +1057,26 @@ this macro matches
 
 =cut
 
- *		  ASCII		     EBCDIC I8
- * U+10FFFF: \xF4\x8F\xBF\xBF	\xF9\xA1\xBF\xBF\xBF	max legal Unicode
- * U+110000: \xF4\x90\x80\x80	\xF9\xA2\xA0\xA0\xA0
- * U+110001: \xF4\x90\x80\x81	\xF9\xA2\xA0\xA0\xA1
+ *                ASCII              EBCDIC I8
+ * U+10FFFF: \xF4\x8F\xBF\xBF   \xF9\xA1\xBF\xBF\xBF    max legal Unicode
+ * U+110000: \xF4\x90\x80\x80   \xF9\xA2\xA0\xA0\xA0
+ * U+110001: \xF4\x90\x80\x81   \xF9\xA2\xA0\xA0\xA1
  */
 #define UTF_START_BYTE_110000_  UTF_START_BYTE(PERL_UNICODE_MAX + 1, 21)
 #define UTF_FIRST_CONT_BYTE_110000_                                         \
                           UTF_FIRST_CONT_BYTE(PERL_UNICODE_MAX + 1, 21)
+
+/* Internal macro when we don't care about it being well-formed, and know we
+ * have two bytes available to read */
+#define UTF8_IS_SUPER_NO_CHECK_(s)                                          \
+     (       NATIVE_UTF8_TO_I8(s[0]) >= UTF_START_BYTE_110000_              \
+      && (   NATIVE_UTF8_TO_I8(s[0]) >  UTF_START_BYTE_110000_              \
+          || NATIVE_UTF8_TO_I8(s[1]) >= UTF_FIRST_CONT_BYTE_110000_))
+
 #define UTF8_IS_SUPER(s, e)                                                 \
-    (   ((e) - (s)) >= UNISKIP_BY_MSB_(20)                                  \
-     && (       NATIVE_UTF8_TO_I8(s[0]) >= UTF_START_BYTE_110000_           \
-         && (   NATIVE_UTF8_TO_I8(s[0]) >  UTF_START_BYTE_110000_           \
-             || NATIVE_UTF8_TO_I8(s[1]) >= UTF_FIRST_CONT_BYTE_110000_)))   \
+    ((((e) - (s)) >= UNISKIP_BY_MSB_(20) && UTF8_IS_SUPER_NO_CHECK_(s))     \
      ? isUTF8_CHAR(s, e)                                                    \
-     : 0
+     : 0)
 
 /*
 =for apidoc Am|bool|UNICODE_IS_NONCHAR|const UV uv
@@ -1201,8 +1206,9 @@ point's representation.
  * First one will convert the overlong to the REPLACEMENT CHARACTER; second
  * will return what the overlong evaluates to */
 #define UTF8_ALLOW_LONG                 0x2000
-#define UTF8_ALLOW_LONG_AND_ITS_VALUE   0x4000
 #define UTF8_GOT_LONG                   UTF8_ALLOW_LONG
+#define UTF8_ALLOW_LONG_AND_ITS_VALUE   0x4000
+#define UTF8_GOT_LONG_WITH_VALUE        UTF8_ALLOW_LONG_AND_ITS_VALUE
 
 /* For back compat, these old names are misleading for overlongs and
  * UTF_EBCDIC. */
@@ -1225,12 +1231,12 @@ point's representation.
 #define UTF8_ALLOW_SURROGATE 0
 
 /* C9 refers to Unicode Corrigendum #9: allows but discourages non-chars */
-#define UTF8_DISALLOW_ILLEGAL_C9_INTERCHANGE                                    \
+#define UTF8_DISALLOW_ILLEGAL_C9_INTERCHANGE                                \
     (UTF8_DISALLOW_SUPER|UTF8_DISALLOW_PERL_EXTENDED|UTF8_DISALLOW_SURROGATE)
-#define UTF8_WARN_ILLEGAL_C9_INTERCHANGE                                        \
+#define UTF8_WARN_ILLEGAL_C9_INTERCHANGE                                    \
                 (UTF8_WARN_SUPER|UTF8_WARN_PERL_EXTENDED|UTF8_WARN_SURROGATE)
 
-#define UTF8_DISALLOW_ILLEGAL_INTERCHANGE                                       \
+#define UTF8_DISALLOW_ILLEGAL_INTERCHANGE                                   \
                   (UTF8_DISALLOW_ILLEGAL_C9_INTERCHANGE|UTF8_DISALLOW_NONCHAR)
 #define UTF8_WARN_ILLEGAL_INTERCHANGE \
                           (UTF8_WARN_ILLEGAL_C9_INTERCHANGE|UTF8_WARN_NONCHAR)
@@ -1239,10 +1245,10 @@ point's representation.
  * to have to deal with any malformations that might be present.  All such will
  * be safely replaced by the REPLACEMENT CHARACTER, unless other flags
  * overriding this are also present. */
-#define UTF8_ALLOW_ANY ( UTF8_ALLOW_CONTINUATION                                \
-                        |UTF8_ALLOW_NON_CONTINUATION                            \
-                        |UTF8_ALLOW_SHORT                                       \
-                        |UTF8_ALLOW_LONG                                        \
+#define UTF8_ALLOW_ANY ( UTF8_ALLOW_CONTINUATION                            \
+                        |UTF8_ALLOW_NON_CONTINUATION                        \
+                        |UTF8_ALLOW_SHORT                                   \
+                        |UTF8_ALLOW_LONG                                    \
                         |UTF8_ALLOW_OVERFLOW)
 
 /* Accept any Perl-extended UTF-8 that evaluates to any UV on the platform, but
@@ -1250,10 +1256,10 @@ point's representation.
 #define UTF8_ALLOW_ANYUV   0
 #define UTF8_ALLOW_DEFAULT UTF8_ALLOW_ANYUV
 
-#define UNICODE_WARN_SURROGATE         0x0001	/* UTF-16 surrogates */
-#define UNICODE_WARN_NONCHAR           0x0002	/* Non-char code points */
-#define UNICODE_WARN_SUPER             0x0004	/* Above 0x10FFFF */
-#define UNICODE_WARN_PERL_EXTENDED     0x0008	/* Above 0x7FFF_FFFF */
+#define UNICODE_WARN_SURROGATE         0x0001   /* UTF-16 surrogates */
+#define UNICODE_WARN_NONCHAR           0x0002   /* Non-char code points */
+#define UNICODE_WARN_SUPER             0x0004   /* Above 0x10FFFF */
+#define UNICODE_WARN_PERL_EXTENDED     0x0008   /* Above 0x7FFF_FFFF */
 #define UNICODE_WARN_ABOVE_31_BIT      UNICODE_WARN_PERL_EXTENDED
 #define UNICODE_DISALLOW_SURROGATE     0x0010
 #define UNICODE_DISALLOW_NONCHAR       0x0020
@@ -1281,11 +1287,11 @@ point's representation.
 
 /* For backward source compatibility, as are now the default */
 #define UNICODE_ALLOW_SURROGATE 0
-#define UNICODE_ALLOW_SUPER	0
-#define UNICODE_ALLOW_ANY	0
+#define UNICODE_ALLOW_SUPER     0
+#define UNICODE_ALLOW_ANY       0
 
-#define UNICODE_BYTE_ORDER_MARK		0xFEFF
-#define UNICODE_IS_BYTE_ORDER_MARK(uv)	UNLIKELY((UV) (uv)                  \
+#define UNICODE_BYTE_ORDER_MARK         0xFEFF
+#define UNICODE_IS_BYTE_ORDER_MARK(uv)  UNLIKELY((UV) (uv)                  \
                                                 == UNICODE_BYTE_ORDER_MARK)
 
 #define LATIN_SMALL_LETTER_SHARP_S      LATIN_SMALL_LETTER_SHARP_S_NATIVE
@@ -1296,15 +1302,15 @@ point's representation.
                             LATIN_CAPITAL_LETTER_A_WITH_RING_ABOVE_NATIVE
 #define LATIN_SMALL_LETTER_A_WITH_RING_ABOVE                                 \
                                 LATIN_SMALL_LETTER_A_WITH_RING_ABOVE_NATIVE
-#define UNICODE_GREEK_CAPITAL_LETTER_SIGMA	0x03A3
-#define UNICODE_GREEK_SMALL_LETTER_FINAL_SIGMA	0x03C2
-#define UNICODE_GREEK_SMALL_LETTER_SIGMA	0x03C3
+#define UNICODE_GREEK_CAPITAL_LETTER_SIGMA      0x03A3
+#define UNICODE_GREEK_SMALL_LETTER_FINAL_SIGMA  0x03C2
+#define UNICODE_GREEK_SMALL_LETTER_SIGMA        0x03C3
 #define GREEK_SMALL_LETTER_MU                   0x03BC
-#define GREEK_CAPITAL_LETTER_MU                 0x039C	/* Upper and title case
+#define GREEK_CAPITAL_LETTER_MU                 0x039C  /* Upper and title case
                                                            of MICRON */
-#define LATIN_CAPITAL_LETTER_Y_WITH_DIAERESIS   0x0178	/* Also is title case */
+#define LATIN_CAPITAL_LETTER_Y_WITH_DIAERESIS   0x0178  /* Also is title case */
 #ifdef LATIN_CAPITAL_LETTER_SHARP_S_UTF8
-#   define LATIN_CAPITAL_LETTER_SHARP_S	        0x1E9E
+#   define LATIN_CAPITAL_LETTER_SHARP_S         0x1E9E
 #endif
 #define LATIN_CAPITAL_LETTER_I_WITH_DOT_ABOVE   0x130
 #define LATIN_SMALL_LETTER_DOTLESS_I            0x131
@@ -1314,42 +1320,28 @@ point's representation.
 #define KELVIN_SIGN                             0x212A
 #define ANGSTROM_SIGN                           0x212B
 
-#define UNI_DISPLAY_ISPRINT	0x0001
-#define UNI_DISPLAY_BACKSLASH	0x0002
-#define UNI_DISPLAY_BACKSPACE	0x0004  /* Allow \b when also
+#define UNI_DISPLAY_ISPRINT 0x0001
+#define UNI_DISPLAY_BACKSLASH   0x0002
+#define UNI_DISPLAY_BACKSPACE   0x0004  /* Allow \b when also
                                            UNI_DISPLAY_BACKSLASH */
-#define UNI_DISPLAY_QQ		(UNI_DISPLAY_ISPRINT                \
+#define UNI_DISPLAY_QQ          (UNI_DISPLAY_ISPRINT                \
                                 |UNI_DISPLAY_BACKSLASH              \
                                 |UNI_DISPLAY_BACKSPACE)
 
 /* Character classes could also allow \b, but not patterns in general */
-#define UNI_DISPLAY_REGEX	(UNI_DISPLAY_ISPRINT|UNI_DISPLAY_BACKSLASH)
+#define UNI_DISPLAY_REGEX       (UNI_DISPLAY_ISPRINT|UNI_DISPLAY_BACKSLASH)
 
 /* Should be removed; maybe deprecated, but not used in CPAN */
 #define SHARP_S_SKIP 2
 
 #define Perl_is_utf8_char_buf(buf, buf_end) isUTF8_CHAR(buf, buf_end)
 
-#define Perl_bytes_to_utf8(mTHX, s, lenp)  Perl_bytes_to_utf8_free_me(aTHX_ s, lenp, NULL)
 typedef enum {
     PL_utf8_to_bytes_overwrite = 0,
     PL_utf8_to_bytes_new_memory,
     PL_utf8_to_bytes_use_temporary,
 } Perl_utf8_to_bytes_arg;
 
-/* INT2PTR() is because this parameter should not be used in this case, but
- * there is a NN assertion for it.  It causes that to pass but to still
- * segfault if wrongly gets used */
-#define Perl_utf8_to_bytes_overwrite(mTHX, s, l)                            \
-        Perl_utf8_to_bytes_(aTHX_ s, l, INT2PTR(U8 **, 1),                  \
-                                  PL_utf8_to_bytes_overwrite)
-#define Perl_utf8_to_bytes_new_pv(mTHX, s, l, f)                            \
-        Perl_utf8_to_bytes_(aTHX_ (U8 **) s, l, f,                          \
-                                  PL_utf8_to_bytes_new_memory)
-#define Perl_utf8_to_bytes_temp_pv(mTHX, s, l)                              \
-        Perl_utf8_to_bytes_(aTHX_ (U8 **) s, l, INT2PTR(U8 **, 1),          \
-                                  PL_utf8_to_bytes_use_temporary)
-
 /* Do not use; should be deprecated.  Use isUTF8_CHAR() instead; this is
  * retained solely for backwards compatibility */
 #define IS_UTF8_CHAR(p, n)      (isUTF8_CHAR(p, (p) + (n)) == n)
